NAME

Generate a JSON file to be uploaded with the codecov bash script.

DESCRIPTION

This is a coverage reporter for Codecov. It generates a JSON file that can be uploaded with the bash script provided by codecov. See https://docs.codecov.io/docs/about-the-codecov-bash-uploader for details.

The generated file will be named codecov.json and will be in the cover_db directory by default.

Nearly all of the code in this distribution was simply copied from Pine Mizune's Devel-Cover-Report-Codecov distribution.

UPLOADING RESULTS

Use the codecov bash script:

cover -report codecovbash
bash <(curl -s https://codecov.io/bash) -t token -f cover_db/codecov.json

CONFIGURATION

DEVEL_COVER_CODECOVBASH_COVER_ALL_STATEMENTS

Since version v0.43

Codecov measures line coverage, while Devel::Cover returns statement coverage. So we have to decide if we want to count a line as covered if at least one statement or all statements in a line are covered.

By default a line is reported as covered if at least one statement is covered.

You can set DEVEL_COVER_CODECOVBASH_COVER_ALL_STATEMENTS to true. Then all statements in a line must be covered.

DEVEL_COVER_CODECOVBASH_COVER_ALL_STATEMENTS=1 cover -report codecovbash

SOURCE

The source code repository for Devel-Cover-Report-Codecovbash can be found at https://github.com/perlpunk/Devel-Cover-Report-Codecovbash.

AUTHOR

Tina Müller <tinita@cpan.org>

CONTRIBUTORS

  • Dave Rolsky <autarch@urth.org>

  • Tina Müller <cpan2@tinita.de>

COPYRIGHT AND LICENSE

This software is Copyright (c) 2019 - 2021 by Pine Mizune.

This is free software, licensed under:

The MIT (X11) License

The full text of the license can be found in the LICENSE file included with this distribution.